==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebExpansionPanelDescriptionMetadata_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebExpansionPanelDescription } from "./WebExpansionPanelDescription";
import { WebExpansionPanelComponentEventArgsDescription } from "./WebExpansionPanelComponentEventArgsDescription";
/**
 * @hidden
 */
var WebExpansionPanelDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebExpansionPanelDescriptionMetadata, _super);
    function WebExpansionPanelDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebExpansionPanelDescriptionMetadata.b = function (a) {
        if (WebExpansionPanelDescriptionMetadata.a == null) {
            WebExpansionPanelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebExpansionPanelDescriptionMetadata.c(WebExpansionPanelDescriptionMetadata.a);
        }
        if (a.k(WebExpansionPanelDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebExpansionPanelDescriptionMetadata.a);
        WebExpansionPanelComponentEventArgsDescriptionMetadata.d(a);
    };
    WebExpansionPanelDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ExpansionPanel");
        a.item("__tagNameWC", "String:igc-expansion-panel");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Open", "Boolean");
        a.item("Disabled", "Boolean");
        a.item("IndicatorPosition", "ExportedType:string:ExpansionPanelIndicatorPosition");
        a.item("IndicatorPosition@stringUnion", "WebComponents;React");
        a.item("IndicatorPosition@names", "Start;End;None");
        a.item("OpeningRef", "EventRef::opening");
        a.item("OpenedRef", "EventRef::opened");
        a.item("ClosingRef", "EventRef::closing");
        a.item("ClosedRef", "EventRef::closed");
    };
    WebExpansionPanelDescriptionMetadata.d = function (a) {
        WebExpansionPanelDescriptionMetadata.b(a);
        a.ad("WebExpansionPanel", function () { return new WebExpansionPanelDescription(); });
        a.ac("WebExpansionPanel", WebExpansionPanelDescriptionMetadata.a);
    };
    WebExpansionPanelDescriptionMetadata.$t = markType(WebExpansionPanelDescriptionMetadata, 'WebExpansionPanelDescriptionMetadata');
    WebExpansionPanelDescriptionMetadata.a = null;
    return WebExpansionPanelDescriptionMetadata;
}(Base));
export { WebExpansionPanelDescriptionMetadata };
/**
 * @hidden
 */
var WebExpansionPanelComponentEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebExpansionPanelComponentEventArgsDescriptionMetadata, _super);
    function WebExpansionPanelComponentEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebExpansionPanelComponentEventArgsDescriptionMetadata.b = function (a) {
        if (WebExpansionPanelComponentEventArgsDescriptionMetadata.a == null) {
            WebExpansionPanelComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebExpansionPanelComponentEventArgsDescriptionMetadata.c(WebExpansionPanelComponentEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebExpansionPanelComponentEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebExpansionPanelComponentEventArgsDescriptionMetadata.a);
        WebExpansionPanelDescriptionMetadata.d(a);
    };
    WebExpansionPanelComponentEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ExpansionPanelComponentEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Detail", "ExportedType:WebExpansionPanel");
    };
    WebExpansionPanelComponentEventArgsDescriptionMetadata.d = function (a) {
        WebExpansionPanelComponentEventArgsDescriptionMetadata.b(a);
        a.ad("WebExpansionPanelComponentEventArgs", function () { return new WebExpansionPanelComponentEventArgsDescription(); });
        a.ac("WebExpansionPanelComponentEventArgs", WebExpansionPanelComponentEventArgsDescriptionMetadata.a);
    };
    WebExpansionPanelComponentEventArgsDescriptionMetadata.$t = markType(WebExpansionPanelComponentEventArgsDescriptionMetadata, 'WebExpansionPanelComponentEventArgsDescriptionMetadata');
    WebExpansionPanelComponentEventArgsDescriptionMetadata.a = null;
    return WebExpansionPanelComponentEventArgsDescriptionMetadata;
}(Base));
export { WebExpansionPanelComponentEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebExpansionPanelDescriptionMetadata_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebExpansionPanelDescription } from "./WebExpansionPanelDescription";
import { WebExpansionPanelComponentEventArgsDescription } from "./WebExpansionPanelComponentEventArgsDescription";
/**
 * @hidden
 */
var WebExpansionPanelDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebExpansionPanelDescriptionMetadata, _super);
    function WebExpansionPanelDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebExpansionPanelDescriptionMetadata.b = function (a) {
        if (WebExpansionPanelDescriptionMetadata.a == null) {
            WebExpansionPanelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebExpansionPanelDescriptionMetadata.c(WebExpansionPanelDescriptionMetadata.a);
        }
        if (a.k(WebExpansionPanelDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebExpansionPanelDescriptionMetadata.a);
        WebExpansionPanelComponentEventArgsDescriptionMetadata.d(a);
    };
    WebExpansionPanelDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ExpansionPanel");
        a.item("__tagNameWC", "String:igc-expansion-panel");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Open", "Boolean");
        a.item("Disabled", "Boolean");
        a.item("IndicatorPosition", "ExportedType:string:ExpansionPanelIndicatorPosition");
        a.item("IndicatorPosition@stringUnion", "WebComponents;React");
        a.item("IndicatorPosition@names", "None;Start;End");
        a.item("OpeningRef", "EventRef::opening");
        a.item("OpenedRef", "EventRef::opened");
        a.item("ClosingRef", "EventRef::closing");
        a.item("ClosedRef", "EventRef::closed");
    };
    WebExpansionPanelDescriptionMetadata.d = function (a) {
        WebExpansionPanelDescriptionMetadata.b(a);
        a.ae("WebExpansionPanel", function () { return new WebExpansionPanelDescription(); });
        a.ad("WebExpansionPanel", WebExpansionPanelDescriptionMetadata.a);
    };
    WebExpansionPanelDescriptionMetadata.$t = markType(WebExpansionPanelDescriptionMetadata, 'WebExpansionPanelDescriptionMetadata');
    WebExpansionPanelDescriptionMetadata.a = null;
    return WebExpansionPanelDescriptionMetadata;
}(Base));
export { WebExpansionPanelDescriptionMetadata };
/**
 * @hidden
 */
var WebExpansionPanelComponentEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebExpansionPanelComponentEventArgsDescriptionMetadata, _super);
    function WebExpansionPanelComponentEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebExpansionPanelComponentEventArgsDescriptionMetadata.b = function (a) {
        if (WebExpansionPanelComponentEventArgsDescriptionMetadata.a == null) {
            WebExpansionPanelComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebExpansionPanelComponentEventArgsDescriptionMetadata.c(WebExpansionPanelComponentEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebExpansionPanelComponentEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebExpansionPanelComponentEventArgsDescriptionMetadata.a);
        WebExpansionPanelDescriptionMetadata.d(a);
    };
    WebExpansionPanelComponentEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ExpansionPanelComponentEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__marshalByValue", "Boolean");
        a.item("Detail", "ExportedType:WebExpansionPanel");
    };
    WebExpansionPanelComponentEventArgsDescriptionMetadata.d = function (a) {
        WebExpansionPanelComponentEventArgsDescriptionMetadata.b(a);
        a.ae("WebExpansionPanelComponentEventArgs", function () { return new WebExpansionPanelComponentEventArgsDescription(); });
        a.ad("WebExpansionPanelComponentEventArgs", WebExpansionPanelComponentEventArgsDescriptionMetadata.a);
    };
    WebExpansionPanelComponentEventArgsDescriptionMetadata.$t = markType(WebExpansionPanelComponentEventArgsDescriptionMetadata, 'WebExpansionPanelComponentEventArgsDescriptionMetadata');
    WebExpansionPanelComponentEventArgsDescriptionMetadata.a = null;
    return WebExpansionPanelComponentEventArgsDescriptionMetadata;
}(Base));
export { WebExpansionPanelComponentEventArgsDescriptionMetadata };
